"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _reactNative = require("react-native");

var _reactNativeReanimated = _interopRequireWildcard(require("react-native-reanimated"));

var _reactNativeRedash = require("react-native-redash");

var _reactNativeSafeAreaContext = require("react-native-safe-area-context");

var _ShareHeader = _interopRequireDefault(require("./ShareHeader"));

var _ShareDetails = _interopRequireDefault(require("./ShareDetails"));

var _ButtonRow = _interopRequireDefault(require("./ButtonRow"));

var _useColor = require("../utils/useColor");

var _useScreenSize = require("../screenSize/useScreenSize");

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const defaultTypes = ['sms', 'email', 'copy'];

const ShareSheet = ({
  children,
  types = defaultTypes,
  isDisplaying,
  details,
  close
}) => {
  const {
    screenSize
  } = (0, _useScreenSize.useScreenSize)();
  const {
    backgroundPrimary
  } = (0, _useColor.useColor)();
  const transition = (0, _reactNativeRedash.useTransition)(isDisplaying);
  const insets = (0, _reactNativeSafeAreaContext.useSafeArea)();
  const opacity = (0, _reactNativeReanimated.interpolate)(transition, {
    inputRange: [0, 1],
    outputRange: [0, 0.5]
  });
  const translation = (0, _reactNativeReanimated.interpolate)(transition, {
    inputRange: [0, 1],
    outputRange: screenSize === 'large' ? [400, 0] : [500, 0]
  });
  const transform = [screenSize === 'large' ? {
    translateX: translation
  } : {
    translateY: translation
  }];
  return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: styles.content
  }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: styles.container
  }, children), /*#__PURE__*/_react.default.createElement(_reactNativeReanimated.default.View, {
    pointerEvents: isDisplaying ? 'auto' : 'none',
    style: [_reactNative.StyleSheet.absoluteFillObject, styles.overlay, {
      opacity
    }]
  }, isDisplaying && /*#__PURE__*/_react.default.createElement(_reactNative.TouchableWithoutFeedback, {
    style: styles.container,
    onPress: close
  }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: styles.container
  }))), /*#__PURE__*/_react.default.createElement(_reactNativeReanimated.default.View, {
    style: [screenSize === 'large' ? styles.largeModal : styles.modal, {
      transform
    }]
  }, /*#__PURE__*/_react.default.createElement(_ShareHeader.default, {
    showDragHandle: screenSize === 'small'
  }), /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [styles.innerContainer, {
      backgroundColor: backgroundPrimary,
      paddingRight: insets.right
    }, screenSize === 'small' && {
      paddingBottom: insets.bottom + 20
    }]
  }, /*#__PURE__*/_react.default.createElement(_ShareDetails.default, details), /*#__PURE__*/_react.default.createElement(_ButtonRow.default, {
    types: types,
    details: details,
    close: close
  }))));
};

const styles = _reactNative.StyleSheet.create({
  container: {
    flex: 1
  },
  content: {
    flex: 1,
    position: 'relative'
  },
  innerContainer: {
    flex: 1,
    paddingTop: 10
  },
  overlay: {
    flex: 1,
    backgroundColor: 'black'
  },
  modal: {
    position: 'absolute',
    bottom: 0,
    right: 0,
    left: 0
  },
  largeModal: {
    position: 'absolute',
    bottom: 0,
    top: 0,
    right: 0,
    width: 405
  }
});

var _default = ShareSheet;
exports.default = _default;
//# sourceMappingURL=ShareSheet.js.map