"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useShare = exports.ShareProvider = void 0;

var _react = _interopRequireWildcard(require("react"));

var _reactNativeSafeAreaContext = require("react-native-safe-area-context");

var _useTranslations = require("./localizations/useTranslations");

var _useScreenSize = require("./screenSize/useScreenSize");

var _ShareSheet = _interopRequireDefault(require("./components/ShareSheet"));

var _useColor = require("./utils/useColor");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const ShareContext = (0, _react.createContext)({
  share: (_, __) => {}
});

const ShareProvider = ({
  children,
  options: defaultOptions
}) => {
  const [isDisplaying, setIsDisplaying] = (0, _react.useState)(false);
  const [details, setDetails] = (0, _react.useState)({});
  const [language, setLanguage] = (0, _react.useState)(defaultOptions && defaultOptions.language);
  const [types, setTypes] = (0, _react.useState)(defaultOptions && defaultOptions.defaultTypes);

  const share = (newDetails, options) => {
    setDetails(newDetails);
    setIsDisplaying(true);

    if (!options) {
      return;
    }

    if (options.language) {
      setLanguage(options.language);
    }

    if (options.types) {
      setTypes(options.types);
    }
  };

  const close = () => setIsDisplaying(false);

  return /*#__PURE__*/_react.default.createElement(_reactNativeSafeAreaContext.SafeAreaProvider, null, /*#__PURE__*/_react.default.createElement(_useColor.AppearanceProvider, {
    theme: defaultOptions && defaultOptions.theme
  }, /*#__PURE__*/_react.default.createElement(_useScreenSize.ScreenSizeProvider, null, /*#__PURE__*/_react.default.createElement(_useTranslations.LocalizationProvider, {
    language: language
  }, /*#__PURE__*/_react.default.createElement(ShareContext.Provider, {
    value: {
      share
    }
  }, /*#__PURE__*/_react.default.createElement(_ShareSheet.default, {
    isDisplaying: isDisplaying,
    details: details,
    close: close,
    types: types
  }, children))))));
};

exports.ShareProvider = ShareProvider;

const useShare = () => (0, _react.useContext)(ShareContext);

exports.useShare = useShare;
//# sourceMappingURL=index.js.map