"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ScreenSizeProvider = exports.useScreenSize = void 0;

var _react = _interopRequireWildcard(require("react"));

var _reactNative = require("react-native");

var _context = require("./context");

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const {
  width: initialWidth,
  height: initialHeight
} = _reactNative.Dimensions.get('window');

const getScreenSize = (orientation, width) => {
  if (orientation === 'landscape' || width > 1300) {
    return 'large';
  } else {
    return 'small';
  }
};

const ScreenSizeProvider = ({
  children
}) => {
  const orientation = initialWidth > initialHeight ? 'landscape' : 'portrait';
  const [screenSize, setScreenSize] = (0, _react.useState)(getScreenSize(orientation, initialWidth));

  const onChange = ({
    window
  }) => {
    const newOrientation = window.width > window.height ? 'landscape' : 'portrait';
    setScreenSize(getScreenSize(newOrientation, window.width));
  };

  (0, _react.useEffect)(() => {
    _reactNative.Dimensions.addEventListener('change', onChange);

    return () => {
      _reactNative.Dimensions.removeEventListener('change', onChange);
    };
  }, []);
  return /*#__PURE__*/_react.default.createElement(_context.ScreenSizeContext.Provider, {
    value: {
      screenSize
    }
  }, children);
};

exports.ScreenSizeProvider = ScreenSizeProvider;

const useScreenSize = () => (0, _react.useContext)(_context.ScreenSizeContext);

exports.useScreenSize = useScreenSize;
//# sourceMappingURL=useScreenSize.js.map