import React from 'react';
import { View, TouchableWithoutFeedback, StyleSheet } from 'react-native';
import Animated, { interpolate } from 'react-native-reanimated';
import { useTransition } from 'react-native-redash';
import { useSafeArea } from 'react-native-safe-area-context';
import ShareHeader from './ShareHeader';
import ShareDetails from './ShareDetails';
import ButtonRow from './ButtonRow';
import { useColor } from '../utils/useColor';
import { useScreenSize } from '../screenSize/useScreenSize';
const defaultTypes = ['sms', 'email', 'copy'];

const ShareSheet = ({
  children,
  types = defaultTypes,
  isDisplaying,
  details,
  close
}) => {
  const {
    screenSize
  } = useScreenSize();
  const {
    backgroundPrimary
  } = useColor();
  const transition = useTransition(isDisplaying);
  const insets = useSafeArea();
  const opacity = interpolate(transition, {
    inputRange: [0, 1],
    outputRange: [0, 0.5]
  });
  const translation = interpolate(transition, {
    inputRange: [0, 1],
    outputRange: screenSize === 'large' ? [400, 0] : [500, 0]
  });
  const transform = [screenSize === 'large' ? {
    translateX: translation
  } : {
    translateY: translation
  }];
  return /*#__PURE__*/React.createElement(View, {
    style: styles.content
  }, /*#__PURE__*/React.createElement(View, {
    style: styles.container
  }, children), /*#__PURE__*/React.createElement(Animated.View, {
    pointerEvents: isDisplaying ? 'auto' : 'none',
    style: [StyleSheet.absoluteFillObject, styles.overlay, {
      opacity
    }]
  }, isDisplaying && /*#__PURE__*/React.createElement(TouchableWithoutFeedback, {
    style: styles.container,
    onPress: close
  }, /*#__PURE__*/React.createElement(View, {
    style: styles.container
  }))), /*#__PURE__*/React.createElement(Animated.View, {
    style: [screenSize === 'large' ? styles.largeModal : styles.modal, {
      transform
    }]
  }, /*#__PURE__*/React.createElement(ShareHeader, {
    showDragHandle: screenSize === 'small'
  }), /*#__PURE__*/React.createElement(View, {
    style: [styles.innerContainer, {
      backgroundColor: backgroundPrimary,
      paddingRight: insets.right
    }, screenSize === 'small' && {
      paddingBottom: insets.bottom + 20
    }]
  }, /*#__PURE__*/React.createElement(ShareDetails, details), /*#__PURE__*/React.createElement(ButtonRow, {
    types: types,
    details: details,
    close: close
  }))));
};

const styles = StyleSheet.create({
  container: {
    flex: 1
  },
  content: {
    flex: 1,
    position: 'relative'
  },
  innerContainer: {
    flex: 1,
    paddingTop: 10
  },
  overlay: {
    flex: 1,
    backgroundColor: 'black'
  },
  modal: {
    position: 'absolute',
    bottom: 0,
    right: 0,
    left: 0
  },
  largeModal: {
    position: 'absolute',
    bottom: 0,
    top: 0,
    right: 0,
    width: 405
  }
});
export default ShareSheet;
//# sourceMappingURL=ShareSheet.js.map