import React, { createContext, useContext, useState } from 'react';
import { SafeAreaProvider } from 'react-native-safe-area-context';
import { LocalizationProvider } from './localizations/useTranslations';
import { ScreenSizeProvider } from './screenSize/useScreenSize';
import ShareSheet from './components/ShareSheet';
import { AppearanceProvider } from './utils/useColor';
const ShareContext = createContext({
  share: (_, __) => {}
});

const ShareProvider = ({
  children,
  options: defaultOptions
}) => {
  const [isDisplaying, setIsDisplaying] = useState(false);
  const [details, setDetails] = useState({});
  const [language, setLanguage] = useState(defaultOptions && defaultOptions.language);
  const [types, setTypes] = useState(defaultOptions && defaultOptions.defaultTypes);

  const share = (newDetails, options) => {
    setDetails(newDetails);
    setIsDisplaying(true);

    if (!options) {
      return;
    }

    if (options.language) {
      setLanguage(options.language);
    }

    if (options.types) {
      setTypes(options.types);
    }
  };

  const close = () => setIsDisplaying(false);

  return /*#__PURE__*/React.createElement(SafeAreaProvider, null, /*#__PURE__*/React.createElement(AppearanceProvider, {
    theme: defaultOptions && defaultOptions.theme
  }, /*#__PURE__*/React.createElement(ScreenSizeProvider, null, /*#__PURE__*/React.createElement(LocalizationProvider, {
    language: language
  }, /*#__PURE__*/React.createElement(ShareContext.Provider, {
    value: {
      share
    }
  }, /*#__PURE__*/React.createElement(ShareSheet, {
    isDisplaying: isDisplaying,
    details: details,
    close: close,
    types: types
  }, children))))));
};

const useShare = () => useContext(ShareContext);

export { ShareProvider, useShare };
//# sourceMappingURL=index.js.map