import React, { useContext } from 'react';
import { createContext } from 'react';
import * as Localization from 'expo-localization';
import { arabic, chinese, english, french, hindi, japanese, portuguese, spanish, swedish } from './languages';
const terms = {
  ar: arabic,
  ch: chinese,
  en: english,
  fr: french,
  hi: hindi,
  jp: japanese,
  pt: portuguese,
  sp: spanish,
  sv: swedish
};
const LocalizationContext = createContext({
  language: 'en'
});
export const LocalizationProvider = ({
  children,
  language
}) => {
  const deviceLocale = Localization.locale;
  const locale = deviceLocale.length > 2 ? deviceLocale.slice(0, 2) : deviceLocale;
  return /*#__PURE__*/React.createElement(LocalizationContext.Provider, {
    value: {
      language: language || locale
    }
  }, children);
};
export const useLocalization = () => {
  const {
    language
  } = useContext(LocalizationContext);

  const translate = term => {
    const t = terms[language] || terms.en;
    return t[term];
  };

  return {
    translate
  };
};
//# sourceMappingURL=useTranslations.js.map