import React from 'react';
import { useState, useEffect, useContext } from 'react';
import { Dimensions } from 'react-native';
import { ScreenSizeContext } from './context';
const {
  width: initialWidth,
  height: initialHeight
} = Dimensions.get('window');

const getScreenSize = (orientation, width) => {
  if (orientation === 'landscape' || width > 1300) {
    return 'large';
  } else {
    return 'small';
  }
};

const ScreenSizeProvider = ({
  children
}) => {
  const orientation = initialWidth > initialHeight ? 'landscape' : 'portrait';
  const [screenSize, setScreenSize] = useState(getScreenSize(orientation, initialWidth));

  const onChange = ({
    window
  }) => {
    const newOrientation = window.width > window.height ? 'landscape' : 'portrait';
    setScreenSize(getScreenSize(newOrientation, window.width));
  };

  useEffect(() => {
    Dimensions.addEventListener('change', onChange);
    return () => {
      Dimensions.removeEventListener('change', onChange);
    };
  }, []);
  return /*#__PURE__*/React.createElement(ScreenSizeContext.Provider, {
    value: {
      screenSize
    }
  }, children);
};

const useScreenSize = () => useContext(ScreenSizeContext);

export { useScreenSize, ScreenSizeProvider };
//# sourceMappingURL=useScreenSize.js.map