import React from 'react';
import { View, Text, TouchableWithoutFeedback, StyleSheet, Platform } from 'react-native';
import * as Linking from 'expo-linking';
import Icon from '../icons/Icon';
import { useColor } from '../utils/useColor';

const Link = ({
  onPress,
  serviceUrl,
  children
}) => {
  if (Platform.OS === 'web' && serviceUrl) {
    console.log('hgot');
    return /*#__PURE__*/React.createElement("a", {
      href: serviceUrl,
      target: "_blank"
    }, children);
  }

  let onPressAction = onPress;

  if (serviceUrl) {
    onPressAction = () => Linking.openURL(serviceUrl);
  }

  return /*#__PURE__*/React.createElement(TouchableWithoutFeedback, {
    onPress: onPressAction
  }, children);
};

const BaseButton = ({
  backgroundColor,
  text,
  icon,
  serviceUrl,
  onPress
}) => {
  const {
    backgroundSecondary,
    fillPrimary
  } = useColor();
  return /*#__PURE__*/React.createElement(View, {
    style: styles.container
  }, /*#__PURE__*/React.createElement(Link, {
    onPress: onPress,
    serviceUrl: serviceUrl
  }, /*#__PURE__*/React.createElement(View, {
    style: [styles.button, {
      backgroundColor: backgroundColor || backgroundSecondary
    }]
  }, /*#__PURE__*/React.createElement(Icon, {
    name: icon,
    size: 30
  }))), /*#__PURE__*/React.createElement(Text, {
    style: [styles.text, {
      color: fillPrimary
    }]
  }, text));
};

const styles = StyleSheet.create({
  container: {
    alignItems: 'center'
  },
  button: {
    padding: 16,
    borderRadius: 18
  },
  text: {
    marginTop: 10,
    fontWeight: '600',
    maxWidth: 72,
    textAlign: 'center'
  }
});
export default BaseButton;
//# sourceMappingURL=BaseButton.js.map